/***************************************************************************
 *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
 *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation (see COPYING)            *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 ***************************************************************************/

#ifndef _TREELISTPOPUP_H
#define _TREELISTPOPUP_H

#include <kpopupmenu.h>

class DTreeListPopup : public KPopupMenu
{
	public:
		enum Action_Type
		{
			e_item = 2002,
			e_cut  = 2003,
			e_copy = 2004,
			e_paste    = 2005,
			e_delete   = 2006,
			e_discon_obj      = 2007,
			e_discon_tree     = 2008,
			e_discon_subtree  = 2009,
			e_discon_parent   = 2010,
			e_unclutter       = 2011,
			e_color           = 2012,
			e_font            = 2013,
			e_properties      = 2014
		};

		DTreeListPopup(QWidget *parent);

	private:
		DTreeListView* m_lstview;
};

#endif // _TREELISTPOPUP_H
